---
layout: post
title: Related Projects
categories: docs docs-explore
permalink: related-projects.html
---

## In the Family

The following projects are based on PhantomJS. They provide extra functionalities.

 * [Casper.js](http://casperjs.org) is useful to build scripted navigation and testing.

 * [Chutzpah](http://chutzpah.codeplex.com) is a JavaScript test runner which runs from Visual Studio, the command line, TeamCity or your favorite CI server. It can run directly on JavaScript, CoffeeScript and TypeScript files and has built in code coverage support.

 * [Ghostbuster](https://github.com/joshbuddy/ghostbuster) simplifies the testing setup with more convenient wrappers.

 * [GhostDriver](https://github.com/detro/ghostdriver) implements Remote WebDriver Wire protocol for PhantomJS. Although it is developed separately, it has been a part of PhantomJS core since PhantomJS 1.8.

 * [Lotte](https://github.com/StanAngeloff/lotte) adds jQuery-like methods, chaining, and more assertion logic.

 * [Poltergeist](https://github.com/jonleighton/poltergeist) is a driver for [Capybara](https://github.com/jnicklas/capybara) so you can run your Capybara tests using PhantomJS.

 * [pjscrape](https://github.com/nrabinowitz/pjscrape) combines PhantomJS with jQuery as a command-line scraping tool.

 * [WebSpecter](https://github.com/jgonera/webspecter) is a BDD-style acceptance test framework for web applications.

 * [conjure](https://github.com/codeactual/conjure) lets you write CasperJS tests in BDD-style modules and run them with variable concurrency. Also provides additional stack tracing, helpers and module bootstrapping.

 * [PhantomJS Google Charts](https://github.com/pstephan1187/PhantomJS-Google-Charts) lets you capture the svg data for charts produced by Google's JSAPI and use it server side. Examples would be to inject the charts into a PDF or to convert it to a JPG. 

## Screenshot Utilities

Several page capture projects utilizing PhantomJS:

 * **command-line**
   * [capturejs](https://github.com/superbrothers/capturejs) (Node.js)
   * [pageres](https://github.com/sindresorhus/pageres) - get screenshots of website(s) in few different resolutions to make sure they are responsive (Node.js) 
   * [phantomjs-screenshots](https://github.com/hggh/phantomjs-screenshots), a system for running screenshot tasks defined in JSON format (Node.js)
 * **web-service**
   * [manet](https://github.com/vbauer/manet) (Node.js)
   * [screenshot-app](https://github.com/visionmedia/screenshot-app) (Node.js)
   * [screenshot-as-a-service](https://github.com/fzaninotto/screenshot-as-a-service) (Node.js)
   * [screenshot-service](https://github.com/arunkjn/screenshot-service) a pure phantomJS project to capture screenshot of any page with various configuration options
   * [screenshot](https://github.com/jegade/Screenshot) (Dancer)
   * [screenshot-webservice](https://github.com/gre/screenshot-webservice) (Play2)
   * [pyshotx](https://github.com/nacholibre/pyshotx) a screenshot server using multiple phantomJS processes and queues (Gevent, Redis)
   * [htmlshots](https://github.com/templateria/htmlshots) a screenshot server based on the WebServer module that accepts both URLs and HTML file uploads 
 * **API**
   * Node.js:
     * [node-webshot](https://github.com/brenden/node-webshot)
     * [pageres](https://github.com/sindresorhus/pageres), a command-line tool and Node.js module to get screenshots of website(s) in few different resolutions to make sure they are responsive (uses Node.js)
   * Django
     * [django-screamshot](https://github.com/makinacorpus/django-screamshot)
   * PHP
     * [PHP Screen](https://github.com/microweber/screen) a PHP interface to Phantom JS to make website screenshots.
   * Sinatra
     * [grabshot](https://github.com/bjeanes/grabshot), a simple Sinatra-based API to take screenshots and respond asynchronously to a provided callback URL.


## Tools

 * [basset](https://github.com/fragphace/basset) command-line website performance sniffer.

 * [Compass Magick](https://github.com/StanAngeloff/compass-magick) is a dynamic image generation for Compass using (among others) PhantomJS.

 * [Confess](https://github.com/jamesgpearce/confess) is small script library that uses PhantomJS to headlessly analyze web pages for the purposes of creating a cache manifest file.

 * [GhostStory](https://github.com/thingsinjars/GhostStory) is a collection of [Cucumber](http://cukes.info) steps for automated CSS testing with SpookyJS, CasperJS, PhantomJS, PhantomCSS and Node.JS.
 
 * [Grover](https://github.com/davglass/grover) is a wrapper to automatically run YUI Test based tests.

 * [Grunt](http://gruntjs.org/) is a task-based command line build tool for JavaScript projects using PhantomJS for unit test automation.

 * [Guard PhantomJS](https://github.com/carhartl/guard-phantomjs) automatically runs PhantomJS using Guard.

 * [phridge](https://github.com/peerigon/phridge) provides an easy way to run scripts in PhantomJS and return results back to node.js.

 * [phantomjs-node](https://github.com/sgentle/phantomjs-node) provides PhantomJS bridge for Node.js applications.

 * [node-phantom](https://github.com/alexscheelmeyer/node-phantom) is a bridge between PhantomJS and Node.js.

 * [phantom-proxy](https://github.com/sheebz/phantom-proxy) provides a proxy interface for PhantomJS which runs inside of node.

 * [phantomas](https://github.com/macbre/phantomas) is a web-performance metrics and hints generation tool.

 * [PhantomCSS](https://github.com/Huddle/PhantomCSS) enables automated visual regression testing.

 * [PhantomFlow](https://github.com/Huddle/PhantomFlow) provides a syntax for describing user flows as tests which can then be visualized as an interactive tree graph. Built on CasperJS, integrates with PhantomCSS and uses D3.js for visualization.

 * [phantomjs-installer](https://github.com/jakoch/phantomjs-installer) provides a PHP [Composer](http://getcomposer.org/) package which installs the PhantomJS binary (Linux, Windows, Mac) into the /bin folder of your project.

 * [phantomjs-maven-plugin](https://github.com/klieber/phantomjs-maven-plugin) is a Maven plugin with the primary purpose of installing the PhantomJS binary and providing a property containing the location of the binary for use within a build. It also provides a goal for executing PhantomJS scripts.

 * ["phantomjs"](https://github.com/Obvious/phantomjs) is a Node.js module to download/install PhantomJS and provide its executable path (and that's all). Used by Grunt in [grunt-lib-phantomjs](https://github.com/gruntjs/grunt-lib-phantomjs) for higher-level use in [grunt-contrib-qunit](https://github.com/gruntjs/grunt-contrib-qunit), etc.

 * [PhantomLint](https://github.com/arthurakay/LintRoller/tree/v1.3.0) uses PhantomJS to run JSLint on JavaScript application code.

 * [PhantomXHR](https://github.com/Huddle/PhantomXHR) isolates UI from server API for fast automated UI testing.


 * [shortcut.io](https://github.com/hukl/shortcut.io) uses PhantomJS to generate the screenshot of the bookmarked web sites.

 * [Slippy](https://github.com/Seldaek/slippy) uses PhantomJS to convert HTML presentations into PDFs that can be e.g. uploaded to SlideShare.

 * [SpookyJS](https://github.com/WaterfallEngineering/SpookyJS) drives CasperJS from Node.js over HTTP or stdio.

 * [Yeoman](http://github.com/yeoman/yeoman) is a robust and opinionated client-side stack, comprised of tools and frameworks that can help developers quickly build beautiful web applications. It uses PhantomJS (via Grunt) as a basis for headless tests.
